```{include} ../README.md
:start-line: 0
:end-line: 1
```

```{note}

If you aren't the person who used the cookiecutter, make sure you init `pre-commit install` and `gitmoji -i` on the CLI before starting to work on this repository!
```

You'll probably not need all the different types of directories here.

Just make sure what each of them is supposed to provide.

The organization roughly follows [diataxis](https://diataxis.fr/), calling what diataxis calls "tutorials" guide, and what diataxis calls "guides" FAQ.

```{toctree}
:maxdepth: 1
:hidden:

guide/index
api
faq/index
notes/index
examples/index
changelog
```
